aboutsummaryrefslogtreecommitdiff
path: root/internal/cmd
diff options
context:
space:
mode:
Diffstat (limited to 'internal/cmd')
-rw-r--r--internal/cmd/trunks/main.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/cmd/trunks/main.go b/internal/cmd/trunks/main.go
index 5680811..7ebf44e 100644
--- a/internal/cmd/trunks/main.go
+++ b/internal/cmd/trunks/main.go
@@ -190,14 +190,14 @@ func workerBuild(oneTime bool) {
}
// workerDocs a goroutine that watch any changes to .adoc files inside
// "_doc" directory and convert them into HTML files.
func workerDocs() {
logp := "workerDocs"
mlog.Outf(`%s: started ...`, logp)
opts := &ciigo.ConvertOptions{
- Root: "_doc",
+ Root: `_www/doc`,
}
err := ciigo.Watch(opts)
if err != nil {
@@ -190,14 +190,14 @@ func workerBuild(oneTime bool) {
}
// workerDocs a goroutine that watch any changes to .adoc files inside
-// "_doc" directory and convert them into HTML files.
+// "_www/doc" directory and convert them into HTML files.
func workerDocs() {
logp := "workerDocs"